bootWild: Wild boostrap for linear regression coefficients

Description Usage Arguments Details Value Author(s) References Examples

View source: R/bootWild.R

Description

Wild boostrap for linear regression coefficients (Description)

Usage

1
bootWild(formula, data, lmodObs, B, multiplier)

Arguments

formula

A string that can be coerced into class 'formula'. Usually of the form response variable \sim predictor variables.A symbolic description of the model to be fitted.

data

data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model.

lmodObs

The observed linear model estimated by least squares. A fitted model object of class inheriting from 'lm'.

B

The number of bootstrap replicates. Usually this will be a single positive integer.

multiplier

A string indicating which multiplier to use as the auxiliary distribution. Options are 'Mammen2', 'MammenC', 'Rademacher', and 'norm'

Details

This function simulates the sampling distribution of simple linear regression coefficients by fixing the covariates and resampling Y_i by fixing X_i and using a zero mean, unit variance auxiliary multiplier variable on the i^{th} residual. There are several common multipliers used for Wild bootstrap. The four multipliers supported by this function are: Mammen's two-point distribution, Mammen's continuous distribution, Rademacher distribution, and the Standard Normal distribution.

Value

A B x (k+1) data frame containing B samples from the distributions of each of the (k+1) model parameters, where k is the number of predictors in the model.

Author(s)

Natalie DelRocco

References

Davison, A.C. and Hinkley, D.V. (1997) Bootstrap Methods and Their Application. Cambridge University Press.

Mammen, E. (1993). Bootstrap and Wild Bootstrap for High Dimensional Linear Models. The Annals of Statistics, 21(1), 255-285. doi: 10.1214/aos/1176349025

Examples

1
2
3
4
5
library(faraway)
data(prostate)
lmod <- lm(lpsa ~ lcavol + age + lweight, prostate)
bootsamps <- bootWild(formula='lpsa ~ lcavol + age + lweight', data=prostate,
                      lmodObs=lmod, B = 1000, multiplier = 'Mammen2' )

ndelrocco/lmBootCompare documentation built on Dec. 10, 2019, 12:38 p.m.