Description Usage Arguments Details Value Author(s)
MSE of a bootstrap sample of simple linear regression coefficients
1 | bootMSE(B, lmodObs, x, ncovs)
|
B |
The number of bootstrap replicates. Usually this will be a single positive integer. |
lmodObs |
The observed linear model estimated by least squares. A fitted model object of class inheriting from 'lm'. |
x |
A B x (k+1) data frame containing B samples from the distributions of each of the (k+1) model parameters, where k is the number of predictors in the model. |
ncovs |
The number of covariates in the observed model. A positive integer. |
This function calculates the mean square error for bootstrap samples of linear regression coefficients.
A vector of size (k+1) containing the mean square error of the bootstrap sample of each regression coefficient.
Natalie DelRocco
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.