Description Usage Arguments Details Value Author(s) References Examples
Residual boostrap for linear regression coefficients (Description)
1 | bootResids(formula, data, lmodObs, B)
|
formula |
A string that can be coerced into class 'formula'. Usually of the form response variable \sim predictor variables.A symbolic description of the model to be fitted. |
data |
data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model. |
lmodObs |
The observed linear model estimated by least squares. A fitted model object of class inheriting from 'lm'. |
B |
The number of bootstrap replicates. Usually this will be a single positive integer. |
This function simulates the sampling distribution of simple linear regression coefficients by first simulating the distribution of the errors (\mathbf{ε}) by the empirical distribution function of the residuals (i.e. resampling residuals with replacement).
A B x (k+1) data frame containing B samples from the distributions of each of the (k+1) model parameters, where k is the number of predictors in the model.
Natalie DelRocco
Davison, A.C. and Hinkley, D.V. (1997) Bootstrap Methods and Their Application. Cambridge University Press.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.