Description Usage Arguments Details Author(s) Examples
View source: R/bootstrapSamples.R
Obtain bootstrap samples for linear regression coefficients using six different methods.
1 | bootstrapSamples(lmodObs, formula, data, B)
|
lmodObs |
The observed linear model estimated by least squares. A fitted model object of class inheriting from 'lm'. |
formula |
A string that can be coerced into class 'formula'. Usually of the form response variable \sim predictor variables. A symbolic description of the model to be fitted. |
data |
data frame, list or environment (or object coercible by as.data.frame to a data frame) containing the variables in the model. |
B |
The number of bootstrap replicates. Usually this will be a single positive integer. |
This function is a wrapper for bootCases, bootResids, and bootWild. This function obtains the bootstrapped sampling distributions for linear regression coefficients obtained in each of six methods: case resampling, residual resampling, Wild bootstrap with Mammen's Two-Point Distribution, Wild bootstrap with Mammen's Continuous Distribution, Wild boostrap with Rademacher Distribution, and Wild bootstrap with Standard Normal Distribution.
Natalie DelRocco
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.