Description Usage Arguments Details Author(s) Examples
View source: R/bootstrapSummary.R
Compare bootstrapping methods for linear regression coefficients using summary statistics.
1 2 | bootstrapSummary(bootList, lmodObs, summaryStats = c("mean", "median",
"Q1", "Q3", "var", "IQR", "se", "MSE"))
|
bootList |
A list containing the bootstrapped sampling distributions of linear regression coefficients. Each element in the list should contain a data frame obtained using one of the six supported bootstrapping methods of size B x (k+1) where k is the number of predictors in the model. Column i of the data frame will be a sample of size B from the sampling distribution of β_{i}. |
lmodObs |
The observed linear model estimated by least squares. A fitted model object of class inheriting from 'lm'. |
summaryStats |
A string or a vector of strings. The desired summary statistics of the sampling of regression coefficients for the function to return. Options are: mean, median, Q1, Q3, IQR, var, se, and MSE. |
This function compares the summary statistics of bootstrapped sampling distributions for linear regression coefficients obtained in each of six methods: case resampling, residual resampling, Wild bootstrap with Mammen's Two-Point Distribution, Wild bootstrap with Mammen's Continuous Distribution, Wild boostrap with Rademacher Distribution, and Wild bootstrap with Standard Normal Distribution.
Natalie DelRocco
1 2 3 4 5 6 7 | library(faraway)
data(prostate)
lmod <- lm(lpsa ~ lcavol + age + lweight, prostate)
bootsamps <- bootstrapSamples(lmodObs=lmod, formula='lpsa ~ lcavol + age + lweight',
data=prostate, B=1000)
bootstrapSummary(bootList = bootsamps, lmodObs = lmod,
summaryStats = c('median', 'var', 'se', 'IQR'))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.