Description Usage Arguments Details Author(s) Examples
View source: R/coefficientPlots.R
Visualize the bootstrapped sampling distribution for linear regression coefficients (Description)
1 | coefficientPlots(lmodObs, bootList)
|
lmodObs |
The observed linear model estimated by least squares. A fitted model object of class inheriting from 'lm'. |
bootList |
A list containing the bootstrapped sampling distributions of linear regression coefficients. Each element in the list should contain a data frame obtained using one of the six supported bootstrapping methods of size B x (k+1) where k is the number of predictors in the model. Column i of the data frame will be a sample of size B from the sampling distribution of β_{i}. |
This function plots the bootstrapped sampling distributions of linear regression coefficients obtained using six different methods: case resampling, residual resampling, Wild bootstrap with Mammen's Two-Point Distribution, Wild bootstrap with Mammen's Continuous Distribution, Wild boostrap with Rademacher Distribution, and Wild bootstrap with Standard Normal Distribution. Each plot contains (k+1) facets where k is the number of predictors in the model. The least squares estimate of each regression coefficient is denoted with a red dashed line.
Natalie DelRocco
1 2 3 4 5 6 | library(faraway)
data(prostate)
lmod <- lm(lpsa ~ lcavol + age + lweight, prostate)
bootsamps <- bootstrapSamples(lmodObs=lmod, formula='lpsa ~ lcavol + age + lweight',
data=prostate, B=1000)
coefficientPlots(lmodObs=lmod, bootList=bootsamps)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.